==> occ.ecr_pattern-0.0.0.tar.gz: occ.ecr_pattern-0.0.0/setup.py <==
import json
import setuptools

kwargs = json.loads(
    """
{
    "name": "occ.ecr_pattern",
    "version": "0.0.0",
    "description": "OCC Pattern to create a ecr based on OCC best practices",
    "license": "MIT",
    "url": "https://github.com/occmundial/occ-ecr-pattern.git",
    "long_description_content_type": "text/markdown",
    "author": "Alex Parra<jparra@occ.com.mx>",
    "bdist_wheel": {
        "universal": true
    },
    "project_urls": {
        "Source": "https://github.com/occmundial/occ-ecr-pattern.git"
    },
    "package_dir": {
        "": "src"
    },
    "packages": [
        "occ.ecr_pattern",
        "occ.ecr_pattern._jsii"
    ],
    "package_data": {
        "occ.ecr_pattern._jsii": [
            "occ-ecr-pattern@0.0.0.jsii.tgz"
        ],
        "occ.ecr_pattern": [
            "py.typed"
        ]
    },
    "python_requires": "~=3.8",
    "install_requires": [
        "aws-cdk-lib>=2.143.0, <3.0.0",
        "constructs>=10.3.0, <11.0.0",
        "jsii>=1.99.0, <2.0.0",
        "publication>=0.0.3",
        "typeguard~=2.13.3"
    ],
    "classifiers": [
        "Intended Audience :: Developers",
        "Operating System :: OS Independent",
        "Programming Language :: JavaScript",
        "Programming Language :: Python :: 3 :: Only",
        "Programming Language :: Python :: 3.8",
        "Programming Language :: Python :: 3.9",
        "Programming Language :: Python :: 3.10",
        "Programming Language :: Python :: 3.11",
        "Typing :: Typed",
        "Development Status :: 5 - Production/Stable",
        "License :: OSI Approved"
    ],
    "scripts": []
}
"""
)

with open("README.md", encoding="utf8") as fp:
    kwargs["long_description"] = fp.read()


setuptools.setup(**kwargs)

==> occ.ecr_pattern-0.0.1.tar.gz: occ.ecr_pattern-0.0.1/setup.py <==
import json
import setuptools

kwargs = json.loads(
    """
{
    "name": "occ.ecr_pattern",
    "version": "0.0.1",
    "description": "OCC Pattern to create an AWS ECR based on OCC way",
    "license": "MIT",
    "url": "https://github.com/occmundial/occ-ecr-pattern.git",
    "long_description_content_type": "text/markdown",
    "author": "Alex Parra<jparra@occ.com.mx>",
    "bdist_wheel": {
        "universal": true
    },
    "project_urls": {
        "Source": "https://github.com/occmundial/occ-ecr-pattern.git"
    },
    "package_dir": {
        "": "src"
    },
    "packages": [
        "occ.ecr_pattern",
        "occ.ecr_pattern._jsii"
    ],
    "package_data": {
        "occ.ecr_pattern._jsii": [
            "occ-ecr-pattern@0.0.1.jsii.tgz"
        ],
        "occ.ecr_pattern": [
            "py.typed"
        ]
    },
    "python_requires": "~=3.8",
    "install_requires": [
        "aws-cdk-lib>=2.143.0, <3.0.0",
        "constructs>=10.3.0, <11.0.0",
        "jsii>=1.99.0, <2.0.0",
        "publication>=0.0.3",
        "typeguard~=2.13.3"
    ],
    "classifiers": [
        "Intended Audience :: Developers",
        "Operating System :: OS Independent",
        "Programming Language :: JavaScript",
        "Programming Language :: Python :: 3 :: Only",
        "Programming Language :: Python :: 3.8",
        "Programming Language :: Python :: 3.9",
        "Programming Language :: Python :: 3.10",
        "Programming Language :: Python :: 3.11",
        "Typing :: Typed",
        "Development Status :: 5 - Production/Stable",
        "License :: OSI Approved"
    ],
    "scripts": []
}
"""
)

with open("README.md", encoding="utf8") as fp:
    kwargs["long_description"] = fp.read()


setuptools.setup(**kwargs)
